.. Sea Bottle Jackal documentation master file, created by
   sphinx-quickstart on Sun Apr  3 21:35:59 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Sea Bottle Jackal's documentation!
=============================================

*This project is used to turn images into videos with a jackal effect.*


.. image:: ../examples/wolf.gif

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   main
   app
   jackal
   seam_carve


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
